@@ -160,6 +160,13 @@ class Factorize(Algorithm):
         self.min_features = min_features
         self.latent_features = latent_features
 
+    def __repr__(self) -> str:
+        return f'{self.__class__.__name__}(factorize_convs={self.factorize_convs},factorize_linears={self.factorize_linears},min_channels={self.min_channels},latent_channels={self.latent_channels},min_features={self.min_features},latent_features={self.latent_features})'
+
+    @staticmethod
+    def required_on_load() -> bool:
+        return True
+
     def match(self, event: Event, state: State) -> bool:
         return event == Event.INIT
 
@@ -177,12 +184,12 @@ class Factorize(Algorithm):
 
         if self.factorize_convs:
             num_factorized = module_surgery.count_module_instances(state.model, FactorizedConv2d)
-            logger.data_fit({
+            logger.log_hyperparameters({
                 LOG_NUM_CONV2D_REPLACEMENTS_KEY: num_factorized,
             })
         if self.factorize_linears:
             num_factorized = module_surgery.count_module_instances(state.model, FactorizedLinear)
-            logger.data_fit({
+            logger.log_hyperparameters({
                 LOG_NUM_LINEAR_REPLACEMENTS_KEY: num_factorized,
             })
 
