@@ -5,7 +5,7 @@
 individual training examples, and only computes weight gradients over the pruned subset, reducing iteration time and
 speeding up training.
 
-The algorithm runs on :attr:`~composer.core.event.Event.INIT` and :attr:`~composer.core.event.Event.AFTER_DATLOADER`.
+The algorithm runs on :attr:`.Event.INIT` and :attr:`.Event.AFTER_DATLOADER`.
 On Event.INIT, it gets the loss function before the model is wrapped. On Event.AFTER_DATALOADER, it applies selective
 backprop if the time is between ``self.start`` and ``self.end``.
 
