@@ -48,8 +48,13 @@ def _num_microbatches_split_mapping(m, num_microbatches: int):
     for k, v in m.items():
         if isinstance(v, torch.Tensor):
             chunked[k] = _num_microbatches_split_tensor(v, num_microbatches)
-        if isinstance(v, (List, Tuple)):
+        elif isinstance(v, (List, Tuple)):
             chunked[k] = _num_microbatches_split_list(v, num_microbatches)
+        elif isinstance(v, (int, float, str, bool)):
+            # Broadcast primitives to all chunks
+            chunked[k] = [v] * num_microbatches
+        else:
+            raise ValueError(f'Unsupported batch type: {type(v)}.')
     num_chunks = len(list(chunked.values())[0])
     return [{k: v[idx] for k, v in chunked.items()} for idx in range(num_chunks)]
 
@@ -74,6 +79,9 @@ def _num_microbatches_split_batch(batch: Any, num_microbatches: int) -> Sequence
     if isinstance(batch, Mapping):  # check for dictionary (hf style)
         return _num_microbatches_split_mapping(batch, num_microbatches)
 
+    if isinstance(batch, (Tuple, list)) and _check_list_is_primitives(batch):  # check for list of primitives
+        return _num_microbatches_split_list(batch, num_microbatches)
+
     if isinstance(batch, (Tuple, List)):  # check for batch on 2nd dimension
         result = []
         for item in batch:
@@ -117,12 +125,36 @@ def _split_mapping(m, microbatch_size: int):
     for k, v in m.items():
         if isinstance(v, torch.Tensor):
             chunked[k] = _split_tensor(v, microbatch_size)
-        if isinstance(v, (List, Tuple)):
+        elif isinstance(v, (List, Tuple)):
             chunked[k] = _split_list(v, microbatch_size)
-    num_chunks = len(list(chunked.values())[0])
+        elif isinstance(v, (int, float, str, bool)):
+            # Defer broadcasting primitives until we know num_chunks
+            pass
+        else:
+            raise ValueError(f'Unsupported batch type: {type(v)}.')
+    num_chunks = 1  # Default to 1 chunks if there are no tensors or everything is primitive
+    if len(chunked.keys()) != 0:
+        num_chunks = len(list(chunked.values())[0])
+    # Broadcast primitives to all chunks
+    for k, v in m.items():
+        if isinstance(v, (int, float, str, bool)):
+            chunked[k] = [v] * num_chunks
     return [{k: v[idx] for k, v in chunked.items()} for idx in range(num_chunks)]
 
 
+def _check_list_is_primitives(l):
+    """Checks if all elements in a list are the same primitive type."""
+    if len(l) == 0:
+        return True
+    first_type = type(l[0])
+    if not isinstance(l[0], (int, float, str, bool)):
+        return False
+    for item in l:
+        if type(item) != first_type:
+            return False
+    return True
+
+
 def _default_split_batch(batch: Any, microbatch_size: int) -> Sequence:
     """Splits batch into chunks of size `microbatch_size` for gradient accumulation.
 
@@ -136,6 +168,8 @@ def _default_split_batch(batch: Any, microbatch_size: int) -> Sequence:
         return _split_tensor(batch, microbatch_size)
     elif isinstance(batch, Mapping):  # check for dictionary (hf style)
         return _split_mapping(batch, microbatch_size)
+    elif isinstance(batch, (Tuple, list)) and _check_list_is_primitives(batch):  # check for list of primitives
+        return _split_list(batch, microbatch_size)
     elif isinstance(batch, (Tuple, List)):  # check for batch on 2nd dimension
         result = []
         for item in batch:
@@ -179,7 +213,7 @@ class DataSpec:
        ... )
 
     Args:
-        dataloader (Iterable): The dataloader, which can be any iterable that yields batches.
+        dataloader (Union[Iterable, torch.utils.data.DataLoader]): The dataloader, which can be any iterable that yields batches.
 
         num_samples (int, optional): The total number of samples in an epoch, across all ranks. This field is used by
             the :class:`.Timestamp` (training progress tracker). If not specified, then ``len(dataloader.dataset)`` is
@@ -214,7 +248,7 @@ class DataSpec:
 
     def __init__(
         self,
-        dataloader: Iterable,
+        dataloader: Union[Iterable, torch.utils.data.DataLoader],
         num_samples: Optional[int] = None,
         num_tokens: Optional[int] = None,
         device_transforms: Optional[Callable[[Batch], Batch]] = None,
@@ -222,7 +256,7 @@ class DataSpec:
         get_num_samples_in_batch: Optional[Callable[[Batch], int]] = None,
         get_num_tokens_in_batch: Optional[Callable[[Batch], int]] = None,
     ) -> None:
-        self.dataloader = dataloader
+        self.dataloader: Union[Iterable, torch.utils.data.DataLoader] = dataloader
         self.num_tokens = num_tokens
         self.device_transforms = self._default_device_transforms if device_transforms is None else device_transforms
         self.split_batch = _default_split_batch if split_batch is None else split_batch
