@@ -7,7 +7,7 @@ from __future__ import annotations
 
 from typing import Any, Dict
 
-__all__ = ["Serializable"]
+__all__ = ['Serializable']
 
 
 class Serializable:
