@@ -13,10 +13,12 @@ define a custom logger and use it when training.
 """
 
 from composer.loggers.cometml_logger import CometMLLogger
+from composer.loggers.console_logger import ConsoleLogger
 from composer.loggers.file_logger import FileLogger
 from composer.loggers.in_memory_logger import InMemoryLogger
 from composer.loggers.logger import Logger
 from composer.loggers.logger_destination import LoggerDestination
+from composer.loggers.mlflow_logger import MLFlowLogger
 from composer.loggers.progress_bar_logger import ProgressBarLogger
 from composer.loggers.remote_uploader_downloader import RemoteUploaderDownloader
 from composer.loggers.tensorboard_logger import TensorboardLogger
@@ -33,4 +35,6 @@ __all__ = [
     'RemoteUploaderDownloader',
     'TensorboardLogger',
     'CometMLLogger',
+    'ConsoleLogger',
+    'MLFlowLogger',
 ]
