@@ -2,10 +2,9 @@
 # SPDX-License-Identifier: Apache-2.0
 
 """A simple example convolutional neural network which can be used to classify MNIST data."""
-from composer.models.classify_mnist.mnist_hparams import MnistClassifierHparams as MnistClassifierHparams
 from composer.models.classify_mnist.model import mnist_model as mnist_model
 
-__all__ = ['mnist_model', 'MnistClassifierHparams']
+__all__ = ['mnist_model']
 
 _task = 'Image Classification'
 _dataset = 'MNIST'
