@@ -19,8 +19,6 @@ from composer.profiler.json_trace_handler import JSONTraceHandler
 from composer.profiler.marker import Marker
 from composer.profiler.profiler import Profiler
 from composer.profiler.profiler_action import ProfilerAction
-from composer.profiler.profiler_hparams import (CyclicProfilerScheduleHparams, JSONTraceHparams, ProfileScheduleHparams,
-                                                TraceHandlerHparams)
 from composer.profiler.profiler_schedule import cyclic_schedule
 from composer.profiler.system_profiler import SystemProfiler
 from composer.profiler.torch_profiler import TorchProfiler
@@ -28,16 +26,12 @@ from composer.profiler.trace_handler import TraceHandler
 
 # All needs to be defined properly for sphinx autosummary
 __all__ = [
-    "Marker",
-    "Profiler",
-    "ProfilerAction",
-    "TraceHandler",
-    "cyclic_schedule",
-    "JSONTraceHandler",
-    "CyclicProfilerScheduleHparams",
-    "ProfileScheduleHparams",
-    "JSONTraceHparams",
-    "TraceHandlerHparams",
-    "SystemProfiler",
-    "TorchProfiler",
+    'Marker',
+    'Profiler',
+    'ProfilerAction',
+    'TraceHandler',
+    'cyclic_schedule',
+    'JSONTraceHandler',
+    'SystemProfiler',
+    'TorchProfiler',
 ]
